<template>
  <div class="bbsl-common-page">
    <div :class="['bbsl-table-search', isAdvanced ? 'advanced-search' : '']">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="5">
          <el-col :span="5">
            <el-form-item label="单位类别">
              <el-select v-model="querys[0].value" placeholder="请选择单位类别" clearable>
                <el-option label="九小场所" value="1" />
                <el-option label="重点单位" value="2" />
                <el-option label="其它" value="3" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="单位名称">
              <el-select v-model="querys[1].value" clearable>
                <el-option v-for="item in units" :key="item.id" :label="item.unitName" :value="item.id" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="超期状态">
              <el-select v-model="querys[4].value" clearable placeholder="请选择">
                <el-option value="1" label="正常" />
                <el-option value="2" label="临期" />
                <el-option value="3" label="超期" />
              </el-select>
            </el-form-item>
            
          </el-col>
          <el-col :span="5">
            <el-form-item label="处理状态">
              <el-select v-model="querys[3].value" clearable placeholder="请选择">
                <el-option value="1" label="待排查" />
                <el-option value="2" label="整改中" />
                <el-option value="3" label="已完成" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button size="small" type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button size="small" icon="el-icon-refresh" @click="handleReset">重置</el-button>
            <el-link :underline="false" type="primary" @click="advanced">
              {{ isAdvanced ? '基础搜索' : '高级搜索' }}
            </el-link>
          </el-col>
        </el-row>
        <el-row :gutter="5">
          <el-col :span="6">
            <el-form-item label="最迟复查时间" prop="checkStartDate">
              <el-date-picker v-model="querys[2].value" clearable type="daterange" range-separator="至"
                start-placeholder="开始日期" end-placeholder="结束日期" value-format="yyyy-MM-dd"></el-date-picker>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" :class="['bbsl-table-content', isAdvanced ? 'advanced-search-table' : '']">
      <div ref="btnPanel" class="bbsl-btn-content">
        <!-- <el-button icon="el-icon-edit" type="warning" @click="handleFc"
          >复查</el-button
        >
        <el-button
          :disabled="!multipleSelection.length"
          icon="el-icon-tickets"
          type="success"
          @click="closeDanger"
          >关闭隐患</el-button
        >-->
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleUpdate"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" />
        <el-table-column type="index" width="55" label="序号" />
        <el-table-column prop="unitName" label="单位名称" show-overflow-tooltip />
        <el-table-column prop="type" label="单位类别" show-overflow-tooltip>
          <template slot-scope="scope">
            <span v-if="scope.row.type == '1'">九小场所</span>
            <span v-if="scope.row.type == '2'">重点单位</span>
            <span v-if="scope.row.type == '3'">其它</span>
          </template>
        </el-table-column>
        <el-table-column sortable prop="latestReviewDate" label="最迟复查时间" show-overflow-tooltip>
          <template slot-scope="scope">
            <div>{{ scope.row.latestReviewDate ? scope.row.latestReviewDate.slice(0, 10) : '' }}</div>
          </template>
        </el-table-column>
        <el-table-column prop="handleStatus" label="处理状态" show-overflow-tooltip>
          <template slot-scope="scope">
            <el-tag v-if="scope.row.handleStatus === '1'" type="warning" effect="dark">排查中</el-tag>
            <el-tag v-if="scope.row.handleStatus === '2'" type="danger" effect="dark">整改中</el-tag>
            <el-tag v-if="scope.row.handleStatus === '3'" type="success" effect="dark">已完成</el-tag>
          </template>
        </el-table-column>
        <el-table-column sortable prop="expireStatus" label="超期状态" show-overflow-tooltip>
          <template slot-scope="scope">
            <span v-if="scope.row.expireStatus == '1'">正常</span>
            <span v-if="scope.row.expireStatus == '2'">临期</span>
            <span v-if="scope.row.expireStatus == '3'">超期</span>
          </template>
        </el-table-column>
        <el-table-column prop="dangerContent" label="隐患内容" show-overflow-tooltip />
        <el-table-column label="隐患图片" min-width="50" prop="imgUrlArray">
          <template slot-scope="scope">
            <template>
              <el-image v-if="scope.row.imgUrlArray" style="width: 100px; height: 100px"
                :src="previewUrl + scope.row.imgUrlArray[0]" :preview-src-list="scope.row.imgUrlArray.map((item) => {
                  return previewUrl + item
                })"></el-image>
            </template>
          </template>
        </el-table-column>
        <el-table-column label="整改后图片" min-width="50" prop="reformImgUrlArray">
          <template slot-scope="scope">
            <template>
              <el-image v-if="scope.row.reformImgUrlArray" style="width: 100px; height: 100px"
                :src="previewUrl + scope.row.reformImgUrlArray[0]" :preview-src-list="scope.row.reformImgUrlArray.map((item) => {
                  return previewUrl + item
                })"></el-image>
            </template>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <CmgtSaftyDangerRectificationFormDialog @refreshList="loadData" :handleFcData="handleFcData" ref="formModal" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CmgtSaftyDangerCheckrecordApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckrecordApi'
import CmgtSaftyDangerRectificationFormDialog
  from '@/views/Manage/saftyDanger/components/CmgtSaftyDangerRectificationFormDialog'
import CmgtSaftyDangerCheckplanApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckplanApi'

export default {
  name: 'CmgtSaftyDangerCheckrecordManage',
  components: {
    CmgtSaftyDangerRectificationFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      handleFcData: [],
      url: {
        delete: '/manager/cmgtSaftyDangerCheckrecord/'
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 't.type',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 't.unitId',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 't.latestReviewDate',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 't.handleStatus',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 't.expireStatus',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      units: [],
      statusList: [],
      types: [],
      previewUrl:
        window.context.portal +
        '/file/onlinePreviewController/v1/getFileById_',
      isShow: false
    }
  },
  created() {
    this.types = dictContracts.getDictItemsFromCache('cmgt_aqyhlx')
    this.statusList = dictContracts.getDictItemsFromCache('yhzt')
    this.statusList.splice(0, 1)
    this.statusList.splice(3, 1)
    console.log(this.statusList)
  },
  mounted() {
  },
  methods: {
    loadAllUnitList() {
      CmgtSaftyDangerCheckrecordApi.loadAllUnit(
        {
          pageBean: { pageSize: -1, page: 1 }
        },
        res => {
          console.log(res)
          this.units = res.rows
          this.tableData.forEach(item => {
            this.units.forEach(val => {
              if (item.unitId == val.id) {
                item.unitName = val.unitName
              }
            })
          })
        }
      )
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
      this.querys[4].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      if (this.querys[4].value) {
        this.queryParam.querys.push(this.querys[4])
      }
      CmgtSaftyDangerCheckrecordApi.CSaftyDangerAbarbeitungList(this.queryParam).then(res => {
        const { data: { value: { rows, total } } } = res
        this.total = total
        this.tableData = rows
        this.loadAllUnitList()
        this.$set(this.tableData)
        this.loading = false
      })
    },

    resetSelecedt() {
      // 重置选中
      this.$refs.multipleSelection.multipleSelection = []
    },
    handleAdd() {
      // 增加
      this.$refs.formModal.add()
    },
    handleSelectionChange(row) {
      this.handleFcData = row
      this.multipleSelection = row.map(item => {
        return item.id
      })
      console.log(this.multipleSelection)
      console.log(row)
    },
    handleFc() {
      // 复查按钮
      // if (this.multipleSelection.length != 1) {
      //   this.$message({
      //     message: '请选择一条需要修改的数据！',
      //     type: 'warning'
      //   })
      // } else {
      //   var row = null
      //   this.tableData.forEach(item => {
      //     if (item.id == this.multipleSelection[0]) {
      //       row = item
      //     }
      //   })
      //   if (row.status === '3') {
      //     this.$message({
      //       message: '该隐患已关闭！',
      //       type: 'warning'
      //     })
      //   } else {
      //     this.$refs.formModal.Update(row)
      //   }
      // }

      this.$refs.formModal.Update()
    },
    closeDanger() {
      CmgtSaftyDangerCheckrecordApi.CSaftyDangerAbarbeitungClose(
        this.multipleSelection
      )
        .then(res => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '关闭成功',
              duration: 2000
            })
            this.queryParam.pageBean.page = 1
            this.loadData()
          }
        })
        .catch(res => {
          this.$notify({
            type: 'error',
            message: res.message,
            duration: 2000,
            offset: 80
          })
        })
      // // 关闭隐患
      // if (this.multipleSelection.length != 1) {
      //   this.$message({
      //     message: '请选择一条需要关闭的隐患信息！',
      //     type: 'warning'
      //   })
      // } else {
      //   var row = null
      //   this.tableData.forEach(item => {
      //     if (item.id == this.multipleSelection[0]) {
      //       row = item
      //     }
      //   })
      //   if (row.status === '3' && row.reviewResult === '1') {
      //     this.$message({
      //       message: '该隐患已关闭！',
      //       type: 'warning'
      //     })
      //   } else if (row.reviewResult != '1') {
      //     this.$message({
      //       message: '该隐患未完成复查不能关闭！',
      //       type: 'warning'
      //     })
      //   } else {
      //     this.openMemoBox(row.id)
      //   }
      // }
    },
    openMemoBox(id) {
      // 弹出框，增加备注信息，修改状态为3为关闭隐患，1为未复查，2复查中
      this.$prompt('请输入备注信息', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消'
      })
        .then(({ value }) => {
          // 关闭信息
          var param = {
            memo: value,
            status: '3',
            id: id
          }
          CmgtSaftyDangerCheckrecordApi.closeSaftyDangerCheckrecord(
            param,
            res => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '关闭成功！',
                  duration: 2000
                })
                this.loadData()
              } else {
                this.$message.warning(response.message)
              }
            }
          )
        })
        .catch(() => {
          this.$message({
            type: 'info',
            message: '取消关闭'
          })
        })
    },
    // 批量删除隐患
    handleDelete() {
      CmgtSaftyDangerCheckrecordApi.CSaftyDangerAbarbeitungDelete(
        this.multipleSelection
      )
        .then(res => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '删除成功',
              duration: 2000
            })
            this.queryParam.pageBean.page = 1
            this.loadData()
          }
        })
        .catch(res => {
          this.$notify({
            type: 'error',
            message: res.message,
            duration: 2000,
            offset: 80
          })
        })
    },
    // 双击修改
    handleUpdate(row, column, cell, event) {
      this.$refs.formModal.showInfo(row)
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    formatUnitName(row, column, cellValue, index) {
      var obj = this.units.find(function (item) {
        if (item.id === row.recipient) {
          //
          return item
        }
      })
      if (obj !== undefined) {
        return obj.unitName
      } else {
        return ''
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
